"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""
import uuid

from qtpy import QtCore
from qtpy.QtCore import QPoint
from qtpy.QtWidgets import QMainWindow

from guiscrcpy.lib.toolkit import UXMapper
from guiscrcpy.ux import Ui_HorizontalPanel


class Panel(QMainWindow, Ui_HorizontalPanel):
    # there was a Dialog in the bracket
    def __init__(self, parent=None, ux_mapper=None, frame=False,
                 always_on_top=True):
        """
        The bottom panel subwindow class for guiscrcpy
        :param parent: The caller of the function
        :param ux_mapper: The UX Mapper toolkit
        :param frame: Boolean (Frame window / Frameless Window)
        :param always_on_top: Boolean (always on top)
        """
        # noinspection PyArgumentList
        QMainWindow.__init__(self)
        Ui_HorizontalPanel.__init__(self)
        self.name = "panel"
        self.uid = uuid.uuid4()
        self.setupUi(self)
        self.parent = parent
        self.oldPos = self.pos()
        __flags = QtCore.Qt.Window
        if not frame:
            __flags |= QtCore.Qt.FramelessWindowHint
        if always_on_top:
            __flags |= QtCore.Qt.WindowStaysOnTopHint
        self.setWindowFlags(__flags)
        if ux_mapper:
            self.ux = ux_mapper
        else:
            self.ux = UXMapper()

    def init(self):
        self.bp_close.clicked.connect(self.quit_window)
        self.backk.clicked.connect(self.ux.key_back)
        self.menuUII.clicked.connect(self.ux.key_menu)
        self.homee.clicked.connect(self.ux.key_home)
        self.powerUII.clicked.connect(self.ux.key_power)
        self.vupp.clicked.connect(self.ux.key_volume_up)
        self.vdownn.clicked.connect(self.ux.key_volume_down)
        self.colorize()
        self.show()

    def colorize(self):
        hexdigest = self.ux.get_sha()[:6]
        self.bp_device_id.setStyleSheet(f"background-color: #{hexdigest};")

    def mousePressEvent(self, event):
        self.oldPos = event.globalPos()

    def mouseMoveEvent(self, event):
        try:
            delta = QPoint(event.globalPos() - self.oldPos)

            self.move(self.x() + delta.x(), self.y() + delta.y())
            self.oldPos = event.globalPos()
        except (TypeError, AttributeError):
            pass

    def quit_window(self):
        for instance in self.parent.child_windows:  # noqa
            # We are checking for any more windows running before killing
            # the main window. self.child_windows has the list of all
            # objects spawned by the main window ui
            # This method checks if we are the last member of the windows
            # spawned and we ourselves are not a member of ourself by
            # checking the uuid generated on creation
            if not instance.isHidden() \
                    and instance.name != "swipe" and instance.uid != \
                    self.uid:
                self.hide()
                break
        else:
            for instance in self.parent.child_windows:  # noqa
                if instance.name == 'swipe' and instance.ux.get_sha() == \
                        self.ux.get_sha():
                    instance.hide()
            self.hide()



#!/usr/bin/env python
"""
Create desktop shortcuts for Windows
"""
from __future__ import print_function

import os
from collections import namedtuple

import win32com.client
from win32com.shell import shell, shellcon

UserFolders = namedtuple("UserFolders", ("home", "desktop", "startmenu"))

scut_ext = 'lnk'
ico_ext = 'ico'


def get_conda_active_env():
    '''Return name of active conda environment or empty string'''
    conda_env = None
    try:
        conda_env = os.environ['CONDA_DEFAULT_ENV']
    except KeyError:
        print("No conda env active, defaulting to base")
        conda_env = ""
    return conda_env


# batch filename to activate the environment
# for Anaconda Python before running command.
conda_env = get_conda_active_env()
ENVRUNNER = """
@ECHO OFF
call %~dp0%activate {0}
echo # run in conda environment "%CONDA_DEFAULT_ENV%":
echo # %*
%*
""".format(conda_env)

_WSHELL = win32com.client.Dispatch("Wscript.Shell")


# Windows Special Folders
# see: https://docs.microsoft.com/en-us/windows/win32/shell/csidl

def get_homedir():
    '''Return home directory:
    note that we return CSIDL_PROFILE, not
    CSIDL_APPDATA, CSIDL_LOCAL_APPDATA,  or CSIDL_COMMON_APPDATA
    '''
    return shell.SHGetFolderPath(0, shellcon.CSIDL_PROFILE, None, 0)


def get_desktop():
    '''Return user Desktop folder'''
    return shell.SHGetFolderPath(0, shellcon.CSIDL_DESKTOP, None, 0)


def get_startmenu():
    '''Return user Start Menu Programs folder
    note that we return CSIDL_PROGRAMS not CSIDL_COMMON_PROGRAMS
    '''
    return shell.SHGetFolderPath(0, shellcon.CSIDL_PROGRAMS, None, 0)


def get_folders():
    """get user-specific folders
    Returns:
    -------
    Named tuple with fields 'home', 'desktop', 'startmenu'
    Example:
    -------
    """
    return UserFolders(get_homedir(), get_desktop(), get_startmenu())


def make_shortcut():
    userfolders = get_folders()

    desktop, startmenu = True, True
    for (create, folder) in ((desktop, userfolders.desktop),
                             (startmenu, userfolders.startmenu)):

        if not os.path.exists(folder):
            os.makedirs(folder)
        dest = os.path.join(folder, "guiscrcpy.lnk")

        wscript = _WSHELL.CreateShortCut(dest)
        wscript.Targetpath = 'guiscrcpy.exe'
        wscript.WorkingDirectory = userfolders.home
        wscript.WindowStyle = 0
        wscript.Description = "An Open Source Android Screen Mirroring System"
        wscript.IconLocation = os.path.join(os.path.abspath(
            os.path.dirname(os.path.dirname(os.path.dirname(__file__)))),
            'ui', 'icons',
            'guiscrcpy_logo_SRj_icon.ico')
        wscript.save()

    return True



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

from qtpy import QtCore
from qtpy.QtCore import QPoint
from qtpy.QtWidgets import QMainWindow

from guiscrcpy.lib.toolkit import UXMapper
from guiscrcpy.ux import Ui_HorizontalPanel


class Panel(QMainWindow, Ui_HorizontalPanel):
    # there was a Dialog in the bracket
    def __init__(self):
        QMainWindow.__init__(self)
        Ui_HorizontalPanel.__init__(self)
        self.setupUi(self)
        self.oldpos = self.pos()
        self.setWindowFlags(
            QtCore.Qt.WindowStaysOnTopHint | QtCore.Qt.FramelessWindowHint
        )

    def init(self):
        self.ux = UXMapper()
        self.backk.clicked.connect(self.ux.key_back)
        self.menuUII.clicked.connect(self.ux.key_menu)
        self.homee.clicked.connect(self.ux.key_home)
        self.powerUII.clicked.connect(self.ux.key_power)
        self.vupp.clicked.connect(self.ux.key_volume_up)
        self.vdownn.clicked.connect(self.ux.key_volume_down)
        self.show()

    def mousePressEvent(self, event):
        self.oldPos = event.globalPos()

    def mouseMoveEvent(self, event):
        try:
            delta = QPoint(event.globalPos() - self.oldPos)

            self.move(self.x() + delta.x(), self.y() + delta.y())
            self.oldPos = event.globalPos()
        except (TypeError, AttributeError):
            pass



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

from guiscrcpy.platform.platform import System

environment = System()


class ColorTerms:
    if environment.system() == "Linux":
        HEADER = "\033[95m"
        OKBLUE = "\033[94m"
        OKGREEN = "\033[92m"
        WARNING = "\033[93m"
        FAIL = "\033[91mERR:"
        ENDC = "\033[0m"
        BOLD = "\033[1m"
        UNDERLINE = "\033[4m"
    else:
        HEADER = ""
        OKBLUE = ""
        OKGREEN = ""
        WARNING = ""
        FAIL = "ERR:"
        ENDC = ""
        BOLD = ""
        UNDERLINE = ""



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'guiscrcpy/ui/mainwindow.ui'
#
# Created by: PyQt5 UI code generator 5.15.0
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(539, 629)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.MinimumExpanding, QtWidgets.QSizePolicy.MinimumExpanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(MainWindow.sizePolicy().hasHeightForWidth())
        MainWindow.setSizePolicy(sizePolicy)
        MainWindow.setMinimumSize(QtCore.QSize(500, 420))
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(10)
        MainWindow.setFont(font)
        icon = QtGui.QIcon()
        icon.addPixmap(QtGui.QPixmap(":/res/ui/guiscrcpy_logo.png"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        MainWindow.setWindowIcon(icon)
        MainWindow.setStyleSheet("QPushButton {\n"
"border-radius: 10px;\n"
"    background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 255, 255, 255), stop:1 rgba(0, 255, 152, 255));\n"
"color: rgb(0, 0, 0);\n"
"}\n"
"QPushButton:pressed {\n"
"border-radius: 10px;\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 255, 255, 255), stop:1 rgba(0, 255, 152, 255));\n"
"color: rgb(0, 0, 0);\n"
"}\n"
".QPushButton:hover {\n"
"border-radius: 10px;\n"
"    background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 199, 199, 255), stop:1 rgba(0, 190, 113, 255));\n"
"color: rgb(0, 0, 0);\n"
" }\n"
".QPushButton#quit{\n"
"                        background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(255, 0, 0, 255), stop:1 rgba(255, 155, 0, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
" }\n"
".QPushButton#quit:hover{             \n"
"    background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(172, 0, 0, 255), stop:1 rgba(175, 106, 0, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
" }\n"
".QPushButton#usbaud{\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:1, stop:0 rgba(0, 0, 255, 255), stop:0.901961 rgba(152, 0, 255, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"}\n"
".QPushButton#usbaud:hover{                        \n"
"    background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(172, 0, 0, 255), stop:1 rgba(175, 106, 0, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"}\n"
".QPushButton#mapnow{\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(253, 0, 255, 255), stop:0.990196 rgba(88, 0, 255, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
" }\n"
".QPushButton#initmapnow{\n"
"background-color: qlineargradient(spread:pad, x1:1, y1:1, x2:0, y2:0, stop:0.0196078 rgba(0, 141, 255, 255), stop:1 rgba(52, 0, 255, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"}\n"
".QPushButton#initmapnow:hover{\n"
"background-color:qlineargradient(spread:pad, x1:1, y1:1, x2:0, y2:0, stop:0.0196078 rgba(0, 72, 131, 255), stop:1 rgba(24, 0, 122, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
" }\n"
".QPushButton#mapnow:hover{\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:1, x2:1, y2:0, stop:0 rgba(199, 0, 255, 255), stop:0.990196 rgba(88, 0, 255, 255));\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"}\n"
".QPushButton#network_button{\n"
"background-color: rgb(10, 10, 10);\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;    \n"
" }\n"
".QPushButton#settings_button{\n"
"background-color: rgb(10, 10, 10);\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;    \n"
" }\n"
".QPushButton#refreshdevices{\n"
"background-color: rgb(10, 10, 10);\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;    \n"
" }\n"
".QPushButton#restart_adb_server{\n"
"background-color: rgb(10, 10, 10);\n"
"color: rgb(0, 0, 0);\n"
"border-radius: 10px;    \n"
" }\n"
"\n"
"\n"
"\n"
"")
        MainWindow.setUnifiedTitleAndToolBarOnMac(False)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(24)
        sizePolicy.setVerticalStretch(25)
        sizePolicy.setHeightForWidth(self.centralwidget.sizePolicy().hasHeightForWidth())
        self.centralwidget.setSizePolicy(sizePolicy)
        self.centralwidget.setMinimumSize(QtCore.QSize(500, 300))
        self.centralwidget.setStyleSheet("")
        self.centralwidget.setObjectName("centralwidget")
        self.gridLayout_5 = QtWidgets.QGridLayout(self.centralwidget)
        self.gridLayout_5.setObjectName("gridLayout_5")
        self.frame = QtWidgets.QFrame(self.centralwidget)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.frame.sizePolicy().hasHeightForWidth())
        self.frame.setSizePolicy(sizePolicy)
        self.frame.setObjectName("frame")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.frame)
        self.verticalLayout.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.verticalLayout.setContentsMargins(7, 1, 7, -1)
        self.verticalLayout.setObjectName("verticalLayout")
        self.gridLayout_4 = QtWidgets.QGridLayout()
        self.gridLayout_4.setSizeConstraint(QtWidgets.QLayout.SetMinimumSize)
        self.gridLayout_4.setVerticalSpacing(1)
        self.gridLayout_4.setObjectName("gridLayout_4")
        self.fullscreen = QtWidgets.QCheckBox(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.fullscreen.sizePolicy().hasHeightForWidth())
        self.fullscreen.setSizePolicy(sizePolicy)
        self.fullscreen.setMinimumSize(QtCore.QSize(10, 20))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.fullscreen.setFont(font)
        icon1 = QtGui.QIcon()
        icon1.addPixmap(QtGui.QPixmap(":/icons/icons/increase-size-option.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.fullscreen.setIcon(icon1)
        self.fullscreen.setObjectName("fullscreen")
        self.gridLayout_4.addWidget(self.fullscreen, 0, 4, 1, 1)
        self.aotop = QtWidgets.QCheckBox(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.aotop.sizePolicy().hasHeightForWidth())
        self.aotop.setSizePolicy(sizePolicy)
        self.aotop.setMinimumSize(QtCore.QSize(10, 20))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.aotop.setFont(font)
        self.aotop.setToolTipDuration(2)
        icon2 = QtGui.QIcon()
        icon2.addPixmap(QtGui.QPixmap(":/icons/icons/fire-symbol.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.aotop.setIcon(icon2)
        self.aotop.setObjectName("aotop")
        self.gridLayout_4.addWidget(self.aotop, 1, 5, 1, 1)
        self.refreshdevices = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.refreshdevices.sizePolicy().hasHeightForWidth())
        self.refreshdevices.setSizePolicy(sizePolicy)
        self.refreshdevices.setMinimumSize(QtCore.QSize(22, 22))
        self.refreshdevices.setMaximumSize(QtCore.QSize(30, 16777215))
        self.refreshdevices.setText("")
        icon3 = QtGui.QIcon()
        icon3.addPixmap(QtGui.QPixmap(":/icons/icons/refresh-page-option.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.refreshdevices.setIcon(icon3)
        self.refreshdevices.setIconSize(QtCore.QSize(15, 15))
        self.refreshdevices.setObjectName("refreshdevices")
        self.gridLayout_4.addWidget(self.refreshdevices, 7, 2, 1, 1)
        self.check_swipe_panel = QtWidgets.QCheckBox(self.frame)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.check_swipe_panel.setFont(font)
        icon4 = QtGui.QIcon()
        icon4.addPixmap(QtGui.QPixmap(":/icons/icons/guiscrcpy_swipe_panel.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.check_swipe_panel.setIcon(icon4)
        self.check_swipe_panel.setObjectName("check_swipe_panel")
        self.gridLayout_4.addWidget(self.check_swipe_panel, 2, 0, 1, 4)
        self.showTouches = QtWidgets.QCheckBox(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.showTouches.sizePolicy().hasHeightForWidth())
        self.showTouches.setSizePolicy(sizePolicy)
        self.showTouches.setMinimumSize(QtCore.QSize(10, 20))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.showTouches.setFont(font)
        icon5 = QtGui.QIcon()
        icon5.addPixmap(QtGui.QPixmap(":/icons/icons/hand-finger-pointing-down.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.showTouches.setIcon(icon5)
        self.showTouches.setObjectName("showTouches")
        self.gridLayout_4.addWidget(self.showTouches, 2, 4, 1, 1)
        self.recScui = QtWidgets.QCheckBox(self.frame)
        self.recScui.setEnabled(True)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.recScui.sizePolicy().hasHeightForWidth())
        self.recScui.setSizePolicy(sizePolicy)
        self.recScui.setMinimumSize(QtCore.QSize(10, 20))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.recScui.setFont(font)
        self.recScui.setToolTipDuration(2)
        icon6 = QtGui.QIcon()
        icon6.addPixmap(QtGui.QPixmap(":/icons/icons/facetime-button.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.recScui.setIcon(icon6)
        self.recScui.setObjectName("recScui")
        self.gridLayout_4.addWidget(self.recScui, 0, 5, 1, 1)
        self.displayForceOn = QtWidgets.QCheckBox(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.displayForceOn.sizePolicy().hasHeightForWidth())
        self.displayForceOn.setSizePolicy(sizePolicy)
        self.displayForceOn.setMinimumSize(QtCore.QSize(10, 20))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.displayForceOn.setFont(font)
        self.displayForceOn.setToolTipDuration(2)
        icon7 = QtGui.QIcon()
        icon7.addPixmap(QtGui.QPixmap(":/icons/icons/bullseye.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.displayForceOn.setIcon(icon7)
        self.displayForceOn.setObjectName("displayForceOn")
        self.gridLayout_4.addWidget(self.displayForceOn, 1, 4, 1, 1)
        self.lock_rotation = QtWidgets.QCheckBox(self.frame)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.lock_rotation.setFont(font)
        icon8 = QtGui.QIcon()
        icon8.addPixmap(QtGui.QPixmap(":/icons/icons/padlock.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.lock_rotation.setIcon(icon8)
        self.lock_rotation.setObjectName("lock_rotation")
        self.gridLayout_4.addWidget(self.lock_rotation, 2, 5, 1, 1)
        self.check_bottom_panel = QtWidgets.QCheckBox(self.frame)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.check_bottom_panel.setFont(font)
        icon9 = QtGui.QIcon()
        icon9.addPixmap(QtGui.QPixmap(":/icons/icons/guiscrcpy_bottom_panel.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.check_bottom_panel.setIcon(icon9)
        self.check_bottom_panel.setObjectName("check_bottom_panel")
        self.gridLayout_4.addWidget(self.check_bottom_panel, 0, 0, 1, 4)
        self.network_button = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.network_button.sizePolicy().hasHeightForWidth())
        self.network_button.setSizePolicy(sizePolicy)
        self.network_button.setToolTipDuration(2)
        self.network_button.setText("")
        icon10 = QtGui.QIcon()
        icon10.addPixmap(QtGui.QPixmap(":/icons/icons/wifi.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.network_button.setIcon(icon10)
        self.network_button.setObjectName("network_button")
        self.gridLayout_4.addWidget(self.network_button, 7, 0, 1, 1)
        self.check_side_panel = QtWidgets.QCheckBox(self.frame)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(10)
        self.check_side_panel.setFont(font)
        icon11 = QtGui.QIcon()
        icon11.addPixmap(QtGui.QPixmap(":/icons/icons/guiscrcpy_side_panel.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.check_side_panel.setIcon(icon11)
        self.check_side_panel.setObjectName("check_side_panel")
        self.gridLayout_4.addWidget(self.check_side_panel, 1, 0, 1, 4)
        self.settings_button = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.settings_button.sizePolicy().hasHeightForWidth())
        self.settings_button.setSizePolicy(sizePolicy)
        self.settings_button.setText("")
        icon12 = QtGui.QIcon()
        icon12.addPixmap(QtGui.QPixmap(":/icons/icons/gear.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.settings_button.setIcon(icon12)
        self.settings_button.setObjectName("settings_button")
        self.gridLayout_4.addWidget(self.settings_button, 7, 1, 1, 1)
        self.device_rotation = QtWidgets.QComboBox(self.frame)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(11)
        self.device_rotation.setFont(font)
        self.device_rotation.setObjectName("device_rotation")
        self.device_rotation.addItem("")
        self.device_rotation.addItem("")
        self.device_rotation.addItem("")
        self.device_rotation.addItem("")
        self.device_rotation.addItem("")
        self.gridLayout_4.addWidget(self.device_rotation, 7, 5, 1, 1)
        self.restart_adb_server = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.restart_adb_server.sizePolicy().hasHeightForWidth())
        self.restart_adb_server.setSizePolicy(sizePolicy)
        self.restart_adb_server.setMinimumSize(QtCore.QSize(22, 22))
        self.restart_adb_server.setMaximumSize(QtCore.QSize(30, 16777215))
        self.restart_adb_server.setToolTipDuration(2)
        self.restart_adb_server.setText("")
        self.restart_adb_server.setIcon(icon7)
        self.restart_adb_server.setIconSize(QtCore.QSize(15, 15))
        self.restart_adb_server.setObjectName("restart_adb_server")
        self.gridLayout_4.addWidget(self.restart_adb_server, 7, 3, 1, 1)
        self.verticalLayout.addLayout(self.gridLayout_4)
        self.devices_view = QtWidgets.QListWidget(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.devices_view.sizePolicy().hasHeightForWidth())
        self.devices_view.setSizePolicy(sizePolicy)
        self.devices_view.setMaximumSize(QtCore.QSize(16777215, 90))
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(9)
        self.devices_view.setFont(font)
        self.devices_view.setAutoFillBackground(True)
        self.devices_view.setStyleSheet("alternate-background-color: rgb(35, 35, 35);")
        self.devices_view.setVerticalScrollBarPolicy(QtCore.Qt.ScrollBarAlwaysOff)
        self.devices_view.setSizeAdjustPolicy(QtWidgets.QAbstractScrollArea.AdjustToContents)
        self.devices_view.setAutoScrollMargin(9)
        self.devices_view.setAlternatingRowColors(True)
        self.devices_view.setIconSize(QtCore.QSize(35, 35))
        self.devices_view.setTextElideMode(QtCore.Qt.ElideMiddle)
        self.devices_view.setProperty("isWrapping", False)
        self.devices_view.setResizeMode(QtWidgets.QListView.Adjust)
        self.devices_view.setViewMode(QtWidgets.QListView.IconMode)
        self.devices_view.setUniformItemSizes(True)
        self.devices_view.setBatchSize(100)
        self.devices_view.setItemAlignment(QtCore.Qt.AlignCenter)
        self.devices_view.setObjectName("devices_view")
        item = QtWidgets.QListWidgetItem()
        item.setTextAlignment(QtCore.Qt.AlignCenter)
        icon13 = QtGui.QIcon()
        icon13.addPixmap(QtGui.QPixmap(":/icons/icons/android.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        item.setIcon(icon13)
        self.devices_view.addItem(item)
        self.verticalLayout.addWidget(self.devices_view)
        self.private_message_box_adb = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.private_message_box_adb.sizePolicy().hasHeightForWidth())
        self.private_message_box_adb.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(11)
        self.private_message_box_adb.setFont(font)
        self.private_message_box_adb.setText("")
        self.private_message_box_adb.setObjectName("private_message_box_adb")
        self.verticalLayout.addWidget(self.private_message_box_adb)
        self.gridLayout_3 = QtWidgets.QGridLayout()
        self.gridLayout_3.setSpacing(0)
        self.gridLayout_3.setObjectName("gridLayout_3")
        self.dimensionDefaultCheckbox = QtWidgets.QCheckBox(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dimensionDefaultCheckbox.sizePolicy().hasHeightForWidth())
        self.dimensionDefaultCheckbox.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(11)
        font.setBold(False)
        font.setItalic(False)
        font.setWeight(50)
        self.dimensionDefaultCheckbox.setFont(font)
        self.dimensionDefaultCheckbox.setChecked(True)
        self.dimensionDefaultCheckbox.setObjectName("dimensionDefaultCheckbox")
        self.gridLayout_3.addWidget(self.dimensionDefaultCheckbox, 0, 3, 1, 2)
        self.label = QtWidgets.QLabel(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label.sizePolicy().hasHeightForWidth())
        self.label.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(11)
        self.label.setFont(font)
        self.label.setObjectName("label")
        self.gridLayout_3.addWidget(self.label, 0, 1, 1, 1)
        self.bitrateText = QtWidgets.QLineEdit(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.bitrateText.sizePolicy().hasHeightForWidth())
        self.bitrateText.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(26)
        font.setBold(True)
        font.setWeight(75)
        self.bitrateText.setFont(font)
        self.bitrateText.setStyleSheet("color: rgb(0, 0, 0);\n"
"border-radius: 10px;\n"
"\n"
"background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, y2:0, stop:0 rgba(0, 255, 255, 255), stop:1 rgba(0, 255, 0, 255));")
        self.bitrateText.setAlignment(QtCore.Qt.AlignCenter)
        self.bitrateText.setObjectName("bitrateText")
        self.gridLayout_3.addWidget(self.bitrateText, 2, 1, 1, 1)
        self.dial = QtWidgets.QDial(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dial.sizePolicy().hasHeightForWidth())
        self.dial.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        font.setPointSize(11)
        self.dial.setFont(font)
        self.dial.setCursor(QtGui.QCursor(QtCore.Qt.SizeHorCursor))
        self.dial.setToolTipDuration(2)
        self.dial.setStyleSheet("background-color: rgb(0, 255, 255);\n"
"color: rgb(255, 0, 127);\n"
"gridline-color: rgb(255, 0, 0);\n"
"selection-background-color: rgb(12, 255, 0);\n"
"\n"
"image: url(:/res/ui/guiscrcpy_logo.png);")
        self.dial.setMinimum(64)
        self.dial.setMaximum(16000)
        self.dial.setSingleStep(2)
        self.dial.setProperty("value", 8000)
        self.dial.setOrientation(QtCore.Qt.Horizontal)
        self.dial.setInvertedAppearance(False)
        self.dial.setInvertedControls(False)
        self.dial.setWrapping(False)
        self.dial.setNotchTarget(20.0)
        self.dial.setNotchesVisible(True)
        self.dial.setObjectName("dial")
        self.gridLayout_3.addWidget(self.dial, 0, 0, 4, 1)
        self.label_2 = QtWidgets.QLabel(self.frame)
        self.label_2.setText("")
        self.label_2.setObjectName("label_2")
        self.gridLayout_3.addWidget(self.label_2, 0, 5, 1, 1)
        self.dimensionSlider = QtWidgets.QSlider(self.frame)
        self.dimensionSlider.setEnabled(False)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dimensionSlider.sizePolicy().hasHeightForWidth())
        self.dimensionSlider.setSizePolicy(sizePolicy)
        self.dimensionSlider.setStyleSheet("color: rgb(255, 255, 255);")
        self.dimensionSlider.setMinimum(320)
        self.dimensionSlider.setMaximum(2048)
        self.dimensionSlider.setProperty("value", 1280)
        self.dimensionSlider.setOrientation(QtCore.Qt.Horizontal)
        self.dimensionSlider.setObjectName("dimensionSlider")
        self.gridLayout_3.addWidget(self.dimensionSlider, 3, 2, 1, 4)
        self.dimensionText = QtWidgets.QLineEdit(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.dimensionText.sizePolicy().hasHeightForWidth())
        self.dimensionText.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(26)
        font.setBold(True)
        font.setWeight(75)
        self.dimensionText.setFont(font)
        self.dimensionText.setStyleSheet("color: rgb(255, 255, 255);\n"
"background-color: rgb(17, 17, 17);\n"
"border-radius: 10px;\n"
"")
        self.dimensionText.setInputMask("")
        self.dimensionText.setMaxLength(32767)
        self.dimensionText.setAlignment(QtCore.Qt.AlignCenter)
        self.dimensionText.setObjectName("dimensionText")
        self.gridLayout_3.addWidget(self.dimensionText, 2, 3, 1, 3)
        self.verticalLayout.addLayout(self.gridLayout_3)
        self.flaglineedit = QtWidgets.QLineEdit(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.flaglineedit.sizePolicy().hasHeightForWidth())
        self.flaglineedit.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Monospace")
        self.flaglineedit.setFont(font)
        self.flaglineedit.setObjectName("flaglineedit")
        self.verticalLayout.addWidget(self.flaglineedit)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setSpacing(5)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.quit = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.quit.sizePolicy().hasHeightForWidth())
        self.quit.setSizePolicy(sizePolicy)
        self.quit.setMinimumSize(QtCore.QSize(45, 45))
        self.quit.setToolTipDuration(2)
        self.quit.setStyleSheet("")
        self.quit.setText("")
        icon14 = QtGui.QIcon()
        icon14.addPixmap(QtGui.QPixmap(":/icons/icons/cross-mark-on-a-black-circle-background.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.quit.setIcon(icon14)
        self.quit.setObjectName("quit")
        self.horizontalLayout.addWidget(self.quit)
        self.pushButton = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.pushButton.sizePolicy().hasHeightForWidth())
        self.pushButton.setSizePolicy(sizePolicy)
        self.pushButton.setMinimumSize(QtCore.QSize(45, 45))
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(11)
        font.setBold(True)
        font.setWeight(75)
        self.pushButton.setFont(font)
        self.pushButton.setToolTipDuration(2)
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout.addWidget(self.pushButton)
        self.abtgit = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.abtgit.sizePolicy().hasHeightForWidth())
        self.abtgit.setSizePolicy(sizePolicy)
        self.abtgit.setMinimumSize(QtCore.QSize(45, 45))
        self.abtgit.setText("")
        icon15 = QtGui.QIcon()
        icon15.addPixmap(QtGui.QPixmap(":/icons/icons/github.logo.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.abtgit.setIcon(icon15)
        self.abtgit.setIconSize(QtCore.QSize(20, 20))
        self.abtgit.setObjectName("abtgit")
        self.horizontalLayout.addWidget(self.abtgit)
        self.usbaud = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(11)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.usbaud.sizePolicy().hasHeightForWidth())
        self.usbaud.setSizePolicy(sizePolicy)
        self.usbaud.setMinimumSize(QtCore.QSize(45, 45))
        self.usbaud.setText("")
        icon16 = QtGui.QIcon()
        icon16.addPixmap(QtGui.QPixmap(":/icons/icons/volume-up-interface-symbol.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.usbaud.setIcon(icon16)
        self.usbaud.setObjectName("usbaud")
        self.horizontalLayout.addWidget(self.usbaud)
        self.initmapnow = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(11)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.initmapnow.sizePolicy().hasHeightForWidth())
        self.initmapnow.setSizePolicy(sizePolicy)
        self.initmapnow.setMinimumSize(QtCore.QSize(45, 45))
        self.initmapnow.setToolTipDuration(3)
        self.initmapnow.setText("")
        icon17 = QtGui.QIcon()
        icon17.addPixmap(QtGui.QPixmap(":/icons/icons/mapper_init.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.initmapnow.setIcon(icon17)
        self.initmapnow.setIconSize(QtCore.QSize(40, 40))
        self.initmapnow.setObjectName("initmapnow")
        self.horizontalLayout.addWidget(self.initmapnow)
        self.executeaction = QtWidgets.QPushButton(self.frame)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.executeaction.sizePolicy().hasHeightForWidth())
        self.executeaction.setSizePolicy(sizePolicy)
        self.executeaction.setMinimumSize(QtCore.QSize(45, 45))
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(11)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.executeaction.setFont(font)
        self.executeaction.setStyleSheet("")
        icon18 = QtGui.QIcon()
        icon18.addPixmap(QtGui.QPixmap(":/icons/icons/small-rocket-ship-silhouette.svg"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
        self.executeaction.setIcon(icon18)
        self.executeaction.setIconSize(QtCore.QSize(20, 16))
        self.executeaction.setObjectName("executeaction")
        self.horizontalLayout.addWidget(self.executeaction)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.progressBar = QtWidgets.QProgressBar(self.frame)
        palette = QtGui.QPalette()
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.WindowText, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.ButtonText, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Base, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(85, 255, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.HighlightedText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255, 128))
        brush.setStyle(QtCore.Qt.NoBrush)
        palette.setBrush(QtGui.QPalette.Active, QtGui.QPalette.PlaceholderText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.WindowText, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.ButtonText, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Base, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(85, 255, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.HighlightedText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255, 128))
        brush.setStyle(QtCore.Qt.NoBrush)
        palette.setBrush(QtGui.QPalette.Inactive, QtGui.QPalette.PlaceholderText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.WindowText, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Button, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Text, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.ButtonText, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Base, brush)
        gradient = QtGui.QLinearGradient(0.0, 0.0, 1.0, 0.0)
        gradient.setSpread(QtGui.QGradient.PadSpread)
        gradient.setCoordinateMode(QtGui.QGradient.ObjectBoundingMode)
        gradient.setColorAt(0.0, QtGui.QColor(0, 255, 255))
        gradient.setColorAt(1.0, QtGui.QColor(0, 255, 0))
        brush = QtGui.QBrush(gradient)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Window, brush)
        brush = QtGui.QBrush(QtGui.QColor(85, 255, 0))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.Highlight, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255))
        brush.setStyle(QtCore.Qt.SolidPattern)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.HighlightedText, brush)
        brush = QtGui.QBrush(QtGui.QColor(255, 255, 255, 128))
        brush.setStyle(QtCore.Qt.NoBrush)
        palette.setBrush(QtGui.QPalette.Disabled, QtGui.QPalette.PlaceholderText, brush)
        self.progressBar.setPalette(palette)
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(10)
        self.progressBar.setFont(font)
        self.progressBar.setStyleSheet("")
        self.progressBar.setProperty("value", 100)
        self.progressBar.setObjectName("progressBar")
        self.verticalLayout.addWidget(self.progressBar)
        self.gridLayout_5.addWidget(self.frame, 1, 0, 1, 1)
        self.frame1 = QtWidgets.QFrame(self.centralwidget)
        self.frame1.setObjectName("frame1")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.frame1)
        self.horizontalLayout_2.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_4 = QtWidgets.QLabel(self.frame1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_4.sizePolicy().hasHeightForWidth())
        self.label_4.setSizePolicy(sizePolicy)
        self.label_4.setMinimumSize(QtCore.QSize(60, 60))
        self.label_4.setMaximumSize(QtCore.QSize(60, 60))
        self.label_4.setText("")
        self.label_4.setPixmap(QtGui.QPixmap(":/res/ui/guiscrcpy_logo.png"))
        self.label_4.setScaledContents(True)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout_2.addWidget(self.label_4)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout()
        self.verticalLayout_2.setSizeConstraint(QtWidgets.QLayout.SetMaximumSize)
        self.verticalLayout_2.setSpacing(0)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.label_3 = QtWidgets.QLabel(self.frame1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Maximum, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.label_3.sizePolicy().hasHeightForWidth())
        self.label_3.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(28)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        self.label_3.setFont(font)
        self.label_3.setStyleSheet("")
        self.label_3.setObjectName("label_3")
        self.verticalLayout_2.addWidget(self.label_3)
        self.build_label = QtWidgets.QLabel(self.frame1)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Maximum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.build_label.sizePolicy().hasHeightForWidth())
        self.build_label.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setFamily("Noto Sans")
        self.build_label.setFont(font)
        self.build_label.setStyleSheet("color: rgb(255, 255, 255);")
        self.build_label.setObjectName("build_label")
        self.verticalLayout_2.addWidget(self.build_label)
        self.horizontalLayout_2.addLayout(self.verticalLayout_2)
        self.gridLayout_5.addWidget(self.frame1, 0, 0, 1, 1)
        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        font = QtGui.QFont()
        font.setFamily("Titillium Web")
        font.setPointSize(10)
        self.statusbar.setFont(font)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "guiscrcpy"))
        MainWindow.setStatusTip(_translate("MainWindow", "GUI by srevinsaju, scrcpy engine by rom1v. Hosted on GitHub\n"
"                https://github.com/srevinsaju/guiscrcpy\n"
"            "))
        self.fullscreen.setText(_translate("MainWindow", "Fullscreen"))
        self.aotop.setToolTip(_translate("MainWindow", "Keep display always on top of other windows"))
        self.aotop.setText(_translate("MainWindow", "Always on Top"))
        self.check_swipe_panel.setText(_translate("MainWindow", "Swipe Panel"))
        self.showTouches.setText(_translate("MainWindow", "Show touches"))
        self.recScui.setToolTip(_translate("MainWindow", "<html><head/><body><p>Record your screen mirroring to your home directory. In Linux, it is in ~guiscrcpy directory. In Windows, it is in C:\\Users\\&lt;username&gt;\\ with the UNIX date, followed by .mp4; For manual configuration and path selection, use the settings icon</p></body></html>"))
        self.recScui.setStatusTip(_translate("MainWindow", "See tooltip"))
        self.recScui.setText(_translate("MainWindow", "Record screen"))
        self.displayForceOn.setToolTip(_translate("MainWindow", "Use your computer screen as your android device\'s HD Display"))
        self.displayForceOn.setText(_translate("MainWindow", "Keep display off "))
        self.lock_rotation.setText(_translate("MainWindow", "Lock Rotation"))
        self.check_bottom_panel.setText(_translate("MainWindow", "Bottom Panel"))
        self.network_button.setToolTip(_translate("MainWindow", "Launch Network Manager"))
        self.check_side_panel.setText(_translate("MainWindow", "Side Panel"))
        self.device_rotation.setItemText(0, _translate("MainWindow", "Default Rotation"))
        self.device_rotation.setItemText(1, _translate("MainWindow", "Potrait"))
        self.device_rotation.setItemText(2, _translate("MainWindow", "Landscape"))
        self.device_rotation.setItemText(3, _translate("MainWindow", "Potrait (flipped)"))
        self.device_rotation.setItemText(4, _translate("MainWindow", "Landscape (flipped)"))
        self.restart_adb_server.setToolTip(_translate("MainWindow", "Restart the adb-server"))
        self.devices_view.setSortingEnabled(True)
        __sortingEnabled = self.devices_view.isSortingEnabled()
        self.devices_view.setSortingEnabled(False)
        item = self.devices_view.item(0)
        item.setText(_translate("MainWindow", "Nothing here"))
        self.devices_view.setSortingEnabled(__sortingEnabled)
        self.dimensionDefaultCheckbox.setText(_translate("MainWindow", "Keep Default Dimensions"))
        self.label.setText(_translate("MainWindow", "Bitrate"))
        self.bitrateText.setInputMask(_translate("MainWindow", "00000 A\\B/s"))
        self.bitrateText.setText(_translate("MainWindow", "8000 KB/s"))
        self.dial.setToolTip(_translate("MainWindow", "Changing the bitrate of the screen mirrorring. Useful to show playback at normal speed without lags"))
        self.dial.setStatusTip(_translate("MainWindow", "Adjust Bitrate. Leave it untouched for defualts"))
        self.dimensionText.setText(_translate("MainWindow", "DEFAULT"))
        self.flaglineedit.setPlaceholderText(_translate("MainWindow", "Enter additional flags to pass to scrcpy"))
        self.quit.setStatusTip(_translate("MainWindow", "Quit GUI and end all subprocess windows "))
        self.pushButton.setStatusTip(_translate("MainWindow", "Reset guiscrcpy configuration files"))
        self.pushButton.setText(_translate("MainWindow", "  RESET  "))
        self.abtgit.setStatusTip(_translate("MainWindow", "Check me out on Github"))
        self.usbaud.setStatusTip(_translate("MainWindow", "Start @rom1v\'s usbaudio. Needs usbaudio to be on PATH"))
        self.initmapnow.setToolTip(_translate("MainWindow", "Initialize mapper"))
        self.initmapnow.setStatusTip(_translate("MainWindow", "Initialize mapper"))
        self.executeaction.setStatusTip(_translate("MainWindow", "Start Scrcpy Executable right now. Please check if Scrcpy is added to path"))
        self.executeaction.setText(_translate("MainWindow", "START SCRCPY"))
        self.progressBar.setStatusTip(_translate("MainWindow", "Progress Bar"))
        self.label_4.setToolTip(_translate("MainWindow", "GUI by srevinsaju, scrcpy engine by rom1v. Hosted on GitHub\n"
"                        https://github.com/srevinsaju/guiscrcpy\n"
"                    "))
        self.label_4.setStatusTip(_translate("MainWindow", "GUI by srevinsaju, scrcpy engine by rom1v. Hosted on GitHub\n"
"                        https://github.com/srevinsaju/guiscrcpy\n"
"                    "))
        self.label_3.setStatusTip(_translate("MainWindow", "GUI by srevinsaju, scrcpy engine by rom1v. Hosted on GitHub\n"
"                        https://github.com/srevinsaju/guiscrcpy\n"
"                    "))
        self.label_3.setText(_translate("MainWindow", "guiscrcpy                          "))
        self.build_label.setText(_translate("MainWindow", "Build"))
from . import rsrc_rc



import os
import platform
import sys
import traceback

import click
import colorama
from qtpy.QtWidgets import QApplication
from qtpy import QtCore, QtWidgets

from .lib.utils import format_colors as fc, show_message_box
from .launcher import bootstrap
from .lib.check import AndroidDebugBridge, ScrcpyNotFoundError, \
    AdbNotFoundError, ScrcpyServerNotFoundError
from .lib.config import InterfaceConfig, InvalidConfigurationError
from .version import VERSION
from . import __doc__ as lic


# initialize colorama on Windows systems
colorama.init()


def show_version(ctx, param, value):  # noqa:
    """Prints the version of the utility"""
    if not value or ctx.resilient_parsing:
        return
    click.echo(fc('{g}guiscrcpy {rst}v{v}', v=VERSION))
    if os.getenv('APPIMAGE'):
        click.echo("Running from AppImage")
    if os.getenv('APPDIR'):
        click.echo("AppDir: {}".format(os.getenv('APPDIR')))
    import inspect
    from PyQt5 import Qt
    _pyqt5_version = [
        '%s = %s' % (k, v) for k, v in
        vars(Qt).items() if
        k.lower().find('version') >= 0 and not inspect.isbuiltin(v)
    ]
    print()
    print("== PyQt5 Version ==")
    print('\n'.join(sorted(_pyqt5_version)))
    print()
    if platform.system() == "Linux":
        print("== CairoSVG version ==")
        from cairosvg import VERSION as CAIRO_VERSION  # noqa:
        print("CairoSVG == {}".format(CAIRO_VERSION))
        print()

    ctx.exit()


def show_license(ctx, param, value):  # noqa:
    """Prints the license of the utility"""
    if not value or ctx.resilient_parsing:
        return
    click.echo(lic)
    ctx.exit()


@click.group(invoke_without_command=True)
@click.pass_context
@click.option('--version', is_flag=True,
              callback=show_version,
              expose_value=False, is_eager=True)
@click.option('--license', '--lic', is_flag=True,
              callback=show_license,
              expose_value=False, is_eager=True)
@click.option('-T',
              '--theme', 'theme',
              default='Breeze',
              help="Set the default theme (based on PyQt5 "
                   "themes - Fusion, Breeze, Windows) "
                   "(stored in configuration, override by --theme-no-cfg)")
@click.option('-W',
              '--hide-wm-frame/--show-wm-frame',
              'hide_wm_frame',
              default=True,
              help="Show window manager border frame.")
@click.option('--debug-disable-scrcpy',
              'debug__disable_scrcpy',
              default=False, is_flag=True,
              help="Do not launch scrcpy even when 'Start Scrcpy' is pressed")
@click.option('-A', '--always-on-top/--disable-always-on-top', 'aot',
              default=True, help="Forces the panels to be always of top")
def cli(ctx, hide_wm_frame=True, aot=True, theme='Breeze',
        debug__disable_scrcpy=False):
    """ guiscrcpy: Graphical user interface for scrcpy"""
    print(fc("\n{b}guiscrcpy {v}{rst}", v=VERSION))
    print(fc("by @srevinsaju"))
    print(fc("{x}https://github.com/srevinsaju/guiscrcpy{rst}\n\n"))
    if ctx.invoked_subcommand is not None:
        return
    try:
        # why this try block?
        # this is because, in case guiscrcpy crashes,
        # it will log the traceback to the terminal
        # but it would not be visible to users without CLI interface
        # enable High DPI scaling
        QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)
        # use HIGH DPI icons
        QApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)
        # init core
        app = QtWidgets.QApplication(sys.argv)
        cfgmgr = InterfaceConfig()
        bootstrap(
            app,
            cfgmgr,
            theme=theme,
            aot=aot,
            hide_wm_frame=hide_wm_frame,
            debug__no_scrcpy=debug__disable_scrcpy)
    except ScrcpyNotFoundError:
        _msg_box = show_message_box(
            text="Scrcpy not found",
            info_text="guiscrcpy could not find scrcpy. "
                      "Make sure you select scrcpy in the dialog box "
                      "or add scrcpy to PATH. You can get the latest release "
                      "of scrcpy from <a href='"
                      "https://github.com/Genymobile/scrcpy'>"
                      "Genymobile/scrcpy 's GitHub Releases</a> "
                      "and select the <pre>scrcpy{ext}</pre> when you run "
                      "guiscrcpy next time".format(
                        ext=".exe" if platform.system() == "Windows" else ""))
        _msg_box.exec_()
        print("Aborting!")
        sys.exit(-1)
    except AdbNotFoundError:
        _msg_box = show_message_box(
            text="ADB not found", info_text="guiscrcpy could not find adb. "
            "Make sure you select adb in the dialog box or add adb to PATH")
        _msg_box.exec_()
        print("Aborting!")
        sys.exit(-1)
    except InvalidConfigurationError:
        _msg_box = show_message_box(
            text="Invalid configuration error",
            info_text="The configuration file for guiscrcpy is invalid. <br>"
                      "This is possibly because a new version of guiscrcpy "
                      "was installed, or the old paths to `adb` and `scrcpy` "
                      "as defined in the configuration file, no longer exists "
                      "in the same path. To fix this error,"
                      "Run  "
                      "<pre>guiscrcpy config -r</pre> on your terminal."
        )
        _msg_box.exec_()
        print("Aborting!")
        sys.exit(-1)
    except ScrcpyServerNotFoundError:
        _msg_box = show_message_box(
            text="Scrcpy server not found error",
            info_text="The configuration file for guiscrcpy is invalid. <br>"
                      "This is possibly because a new version of guiscrcpy "
                      "was installed, or the old paths to `adb` and `scrcpy` "
                      "as defined in the configuration file, no longer exists "
                      "in the same path. To fix this error,"
                      "Run  "
                      "<pre>guiscrcpy config -r</pre> on your terminal."
        )
        _msg_box.exec_()
        print("Aborting!")
        sys.exit(-1)
    except Exception:  # noqa:
        error_message = traceback.format_exc(chain=True)
        print(error_message)
        _msg_box = show_message_box(
            text="Error: Unhandled exception",
            info_text="<pre>{error_message}</pre>"
                      "Please report this, if its a bug, to <a href="
                      "'https://github.com/srevinsaju/guiscrcpy/issues'>"
                      "guiscrcpy bug tracker</a> as it will help to improve "
                      "the next release.".format(error_message=error_message)
        )
        _msg_box.exec_()
        print("Aborting!")
        sys.exit(-1)


@cli.command()
@click.option('--device-id', 'device_id',
              help="Sets the device-id for mapper to configure "
                   " (optional, needed for multiple devices)")
@click.option('-r', '--reset', 'reset', is_flag=True,
              help="Reset guiscrcpy's mapper configuration file")
def mapper(device_id=None, reset=False):
    """Run the guiscrcpy mapper"""
    cfgmgr = InterfaceConfig()
    config = cfgmgr.get_config()
    mapper_cfg_path = os.path.join(
        cfgmgr.get_cfgpath(), 'guiscrcpy.mapper.json'
    )
    if reset:
        # A ternary version of removing a file if it exists
        # https://stackoverflow.com/q/10840533/
        mapper_configuration_file_exists = os.remove(mapper_cfg_path) if \
            os.path.exists(mapper_cfg_path) else None
        if mapper_configuration_file_exists:
            print("guiscrcpy mapper configuration file has been removed.")
            print("Removed {}".format(mapper_configuration_file_exists))
        else:
            print("guiscrcpy mapper configuration is not created yet.")
        return

    if os.getenv('GUISCRCPY_ADB'):
        adb_path = os.getenv('GUISCRCPY_ADB')
    else:
        adb_path = config['adb']
    adb = AndroidDebugBridge(adb_path)
    adb_devices_list = adb.devices()
    if len(adb_devices_list) == 0:
        print("E: No devices found")
        sys.exit(1)
    elif len(adb_devices_list) == 1:
        mapper_device_id = adb_devices_list[0][0]
    elif not device_id:
        print("Please pass the --device-id <device_id> to initialize "
              "the mapper")
        sys.exit(1)
    else:
        mapper_device_id = device_id

    from guiscrcpy.lib.mapper.mapper import Mapper
    # Initialize the mapper if it is called.
    adb = AndroidDebugBridge(path=cfgmgr.get_config().get('adb'))
    mp = Mapper(mapper_device_id, adb=adb, config_path=mapper_cfg_path)
    if not os.path.exists(
            os.path.join(cfgmgr.get_cfgpath(), 'guiscrcpy.mapper.json')):
        print("guiscrcpy.mapper.json does not exist. ")
        print("Initializing Mapper Configuration for the first time use.")
        mp.initialize(initialize_qt=True)
    else:
        mp.read_configuration()
        print("guiscrcpy.mapper.json found. Starting the mapper...")
        print("Your keyboard is being listened by guiscrcpy-mapper")
        print("pressing any key will trigger the position.")
        print()
        print('If you would like to register new keys, pass --mapper-reset')
        print("\nInitializing\n\n")
        mp.listen_keypress()
        print("Done!")


@cli.command('adb')
@click.argument('args', nargs=-1)
def adb_cli(args):
    """Create an interface with the Android Debugging bridge"""
    cfgmgr = InterfaceConfig()
    config = cfgmgr.get_config()
    if os.getenv('GUISCRCPY_ADB'):
        adb_path = os.getenv('GUISCRCPY_ADB')
    else:
        adb_path = config['adb']
    print("Interfacing guiscrcpy-adb")
    os.system('{} {}'.format(adb_path, ' '.join(args)))
    pass


@cli.command()
@click.argument('args', nargs=-1)
def scrcpy(args):
    """Create an interface with scrcpy"""
    cfgmgr = InterfaceConfig()
    config = cfgmgr.get_config()
    if os.getenv('GUISCRCPY_SCRCPY'):
        scrcpy_path = os.getenv('GUISCRCPY_SCRCPY')
    else:
        scrcpy_path = config['scrcpy']
    print("Interfacing guiscrcpy-scrcpy")
    os.system('{} {}'.format(scrcpy_path, ' '.join(args)))
    pass


@cli.command('config')
@click.option('-r', '--reset', 'reset', is_flag=True,
              help="Reset the configuration files")
def _config(reset=False):
    """View / Edit the configuration file"""
    cfgmgr = InterfaceConfig(load=False)
    if reset:
        cfgmgr.reset_config()
        click.echo("Configuration file resetted successfully.")
        sys.exit(0)
    cfgmgr.load_config()
    print(cfgmgr)


@cli.command()
def fast_init():
    """Init scrcpy before guiscrcpy"""
    cfgmgr = InterfaceConfig()
    print(cfgmgr)


if __name__ == "__main__":
    cli()



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import json
import os
import shutil
from guiscrcpy.platform import platform


class InvalidConfigurationError(RuntimeError):
    pass


class InterfaceConfig:
    def __init__(self, load=True):
        """
        Manages guiscrcpy's configuration files
        """
        self.os = platform.System()
        self.cfgpath = self.os.cfgpath()
        self.paths = self.os.paths()
        self.config = {
            'paths': self.paths,
            'scrcpy': None,
            'adb': None,
            'panels': {
                'swipe': True,
                'bottom': True,
                'toolkit': True
            },
            'mapper': '',
            'sha_shift': 5,
            'scrcpy-server': None,
            'dimension': None,
            'swtouches': False,
            'bitrate': 8000,
            'fullscreen': False,
            'dispRO': False,
            'extra': "",
            'cmx': "",
            'device': {},
            'theme': 'Breeze'
        }
        self.json_file = 'guiscrcpy.json'
        if load:
            self.load_config()

    def load_config(self):
        self.check_file()
        self.validate()

    def validate(self):
        # check scrcpy and adb are not None, else replace it with original
        # values
        if os.getenv('APPIMAGE') is not None:
            # no need further configuration for adb, scrcpy and scrcpy_server
            self.config['adb'] = os.getenv('GUISCRCPY_ADB')
            self.config['scrcpy'] = os.getenv('GUISCRCPY_SCRCPY')
            return True
        if self.config['adb'] is None:
            adb_path = shutil.which('adb')
            self.config['adb'] = adb_path
        else:
            _adb_path = self.config['adb']
            if not os.path.exists(_adb_path):
                raise InvalidConfigurationError(
                    "The configuration key 'adb' is "
                    "invalid. {} does not exist. "
                    "If you did not set it on purpose, "
                    "run `guiscrcpy config -r` to reset "
                    "the configuration".format(
                        self.config['adb'])
                )
        if self.config['scrcpy'] is None:
            scrcpy_path = shutil.which('scrcpy')
            self.config['scrcpy'] = scrcpy_path
        else:
            _scrcpy_path = self.config['scrcpy']
            if not os.path.exists(_scrcpy_path):
                raise InvalidConfigurationError(
                    "The configuration key 'scrcpy' is "
                    "invalid. {} does not exist. "
                    "If you did not set it on purpose, "
                    "run `guiscrcpy config -r` to reset "
                    "the configuration".format(
                        self.config['scrcpy'])
                )
        if (self.config['scrcpy-server'] is not None) and (
                platform.System() == "Windows"):
            os.environ['SCRCPY_SERVER_PATH'] = self.config['scrcpy-server']
        return True

    def __setitem__(self, key, value):
        self.config[key] = value
        self.write_file()

    def __getitem__(self, item):
        return self.config.get(item)

    def get_config(self):
        return self.config

    def get_scrcpy(self):
        if self.config['scrcpy'] is not None:
            return self.config['scrcpy']
        else:
            return None

    def get_adb(self):
        if self.config['adb'] is not None:
            return self.config['adb']
        else:
            return None

    def get_cfgpath(self):
        return self.cfgpath

    def read_file(self):
        with open(os.path.join(self.cfgpath, self.json_file), 'r') as f:
            config = json.load(f)
        self.update_config(config)

    def write_file(self):
        with open(os.path.join(self.cfgpath, self.json_file), 'w') as f:
            json.dump(self.config, f, indent=4, sort_keys=True)

    def check_file(self):

        if not os.path.exists(self.cfgpath):
            os.makedirs(self.cfgpath)
        if not os.path.exists(os.path.join(self.cfgpath, self.json_file)):
            self.write_file()
        self.read_file()

    def update_config(self, new_conf):
        for i in new_conf:
            for j in self.config:
                if i == j:
                    self.config[i] = new_conf[i]

    def reset_config(self):
        os.remove(os.path.join(self.get_cfgpath(), self.json_file))
        return True

    def __repr__(self):
        return 'GuiscrcpyConfig({}, "{}")'.format(
            json.dumps(self.config, indent=4),
            self.cfgpath
        )



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import json
import os
import time
import uuid

from qtpy import QtWidgets
from qtpy.QtCore import QThread

from pynput import keyboard

from guiscrcpy.lib.check import AdbRuntimeError
from guiscrcpy.lib.mapper.ux import MapperUI

fixed_pos = [0.0, 0.0]
final_pos = [0.0, 0.0]

json_file = 'guiscrcpy.mapper.json'


class Mapper:
    def __init__(self, device_id, adb, config_path=None):
        self.config = dict()
        self._device_id = device_id
        self.app = None
        self.adb = adb
        self.adb.command('wait-for-any-device')
        self.window = None
        self.guiscrcpy_mapper_json = config_path
        self.dimensions = adb.get_dimensions(device_id)
        if self.check_orientation() == 1:
            # reverse the detected dimensions.
            # possibly the device is landscape / not the default
            # orientation as detected by Android Window Manager
            self.dimensions = self.dimensions[::-1]

    def check_orientation(self):
        proc = self.adb.shell("dumpsys input")
        e_code = proc.wait(500)
        if e_code != 0:
            # process failed
            raise AdbRuntimeError(
                'adb failed with {ecode} when trying to '
                'execute command `adb dumpsys input`'.format(ecode=e_code))
        out, err = proc.communicate()
        out, err = out.decode(), err.decode()
        if 'SurfaceOrientation' in out:
            # SurfaceOrientation gives the idea if the device is
            # landscape or portait. SurfaceOrientation: 1 mentions that
            # the mobile is oriented in the landscape orientation
            # SugrfaceOrientation: 0 indicates, default
            print("Detected SurfaceOrientation, processing...")
            if "SurfaceOrientation: 0" in out:
                print("Detected Portait orientation...")
                return 0
            elif "SurfaceOrientation: 1" in out:
                print("Detected Landscape orientation...")
                return 1
            else:
                print("Failed to detect orientation from device. "
                      "Fallback to 0")
                return 0
        else:
            print("Failed to detect Orientation. SurfaceOrientation"
                  " key was not found")
            return 0

    def set_device_id(self, device_id):
        """
        sets the internal device id to the :param
        :param device_id:
        :type device_id:
        :return:
        :rtype:
        """
        self._device_id = device_id

    def get_device_id(self):
        return self._device_id

    def get_screenshot(self):
        """
        Gets the screenshot using `adb screncap` command
        :return:
        :rtype:
        """
        print("Make sure your phone display is switched on.")
        uid = uuid.uuid4().hex  # generate a random seed
        print("Generating Screenshot: {}".format(uid))

        # capture screenshot using `adb screencap`
        print("Please wait. A full definition screenshot is being captured")

        adb_screencap_process = self.adb.command(
            'shell screencap -p /sdcard/{uid}.png'.format(
                uid=uid
            ),
            device_id=self._device_id
        )
        adb_screencap_process_ecode = adb_screencap_process.wait(500)
        if adb_screencap_process_ecode != 0:
            print("Screenshot failed. Exiting")
            print(adb_screencap_process.stdout.read().decode('utf-8'))
            return
        # sleep for two seconds so that the image is processed
        time.sleep(2)

        # pull screenshot from android using `adb pull`
        adb_pull_process = self.adb.command(
            'pull /sdcard/{uid}.png {dest}'.format(
                uid=uid,
                dest=os.path.dirname(self.guiscrcpy_mapper_json)
            ),
            device_id=self._device_id
        )
        adb_pull_process_ecode = adb_pull_process.wait(500)

        if adb_pull_process_ecode != 0:
            print("Screenshot pull failed. Exiting")
            print(adb_pull_process.stdout.read().decode('utf-8'))
            return

        # sleep for 1 second to get capture time
        time.sleep(1)

        # remove data from user sdcard
        self.adb.command(
            "shell rm /sdcard/{uid}.png".format(uid=uid),
            device_id=self._device_id
        )
        print("[LOG] Screenshot captured. Saved to {cfgpath}".format(
            cfgpath=os.path.dirname(self.guiscrcpy_mapper_json)))
        return os.path.join(os.path.dirname(self.guiscrcpy_mapper_json),
                            '{uid}.png'.format(uid=uid))

    # The following functions handle key events on the mapper
    def on_key_press(self, key):
        try:
            if key.char in self.config.keys():
                print("[KEY] Hotkey command executing")
                position_to_tap = self.config.get(key.char)
                c = self.adb.command(
                    'shell input tap {} {}'.format(*position_to_tap),
                    device_id=self.get_device_id()
                )
                print(c.stdout.read().decode('utf-8'))
                print("[KEY][COMPLETE]")

        except AttributeError:
            if key == keyboard.Key.shift:
                print("[KEY][MOD] Shift key")
            elif key == keyboard.Key.esc:
                print("[KEY][ESC] Aborting")
                return False
            else:
                print("[KEY][MOD] Special key {}".format(key))

    def listen_keypress(self):
        """
        Listens to keypress using pynput and executes self.on_key_press
        on every keydown
        :return:
        :rtype:
        """
        print(
            "[SERVER] LISTENING VALUES:"
            "Your keys are being listened by server. "
        )
        try:
            with keyboard.Listener(on_press=self.on_key_press) as listener:
                listener.join()
        except KeyboardInterrupt:
            print("guiscrcpy-mapper aborted on user request")

    # configuration
    def read_configuration(self):
        if not os.path.exists(self.guiscrcpy_mapper_json):
            self.create_configuration()
        with open(self.guiscrcpy_mapper_json, 'r', encoding='utf-8') as f:
            self.config.update(json.load(f))

    def create_configuration(self):
        with open(self.guiscrcpy_mapper_json, 'w') as w:
            json.dump(self.config, w)
        print("Wrote configuration file.")

    def add_position(self, char, position):
        self.config[char] = position

    # initialize
    def initialize(self, initialize_qt=False):
        """
        Initializes GUI to set keys to mapper
        :return:
        :rtype:
        """
        print("Setting up guiscrcpy-mapper for the first time use...")
        print("Intializing GUI window")
        if __name__ == '__main__' or initialize_qt:
            print("Creating QtCore window Application instance")
            self.app = QtWidgets.QApplication([])
        self.window = MapperUI(
            self,
            self.get_screenshot(),
            self.dimensions,
            fixed_pos=fixed_pos,
            final_pos=final_pos
        )
        self.app.processEvents()
        self.app.exec_()


class MapperAsync(QThread):
    def __init__(self, parent, device_id, adb, initialize=True,
                 config_path=None):
        QThread.__init__(self, parent)
        self.parent = parent
        self.adb = adb
        self.device_id = device_id
        self.initialize = initialize
        self._config_path = config_path

    def run(self):
        mp = Mapper(self.device_id, adb=self.adb,
                    config_path=self._config_path)
        if self.initialize:
            mp.initialize(initialize_qt=False)
        else:
            mp.read_configuration()
            mp.listen_keypress()



"""

GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

"""
from qtpy.QtWidgets import QMessageBox
from qtpy import QtGui, QtCore, QtWidgets
from qtpy.QtCore import Qt
from qtpy.QtGui import QPixmap


class MapperUI(QtWidgets.QWidget):
    """
    Guiscrcpy Mapper User Interface
    configuration an button
    mapping
    """
    def __init__(self, core, screenshot_path, dimensions,
                 fixed_pos=[0.0, 0.0], final_pos=[0.0, 0.0]):
        self.fixed_pos = fixed_pos
        self.final_pos = final_pos
        self.core = core
        self.last_found_point = None
        self.image = None
        QtWidgets.QWidget.__init__(self)
        self.build_user_interface()
        self.screenshot_path = screenshot_path
        self.dimensions = dimensions
        self.set_screenshot_to_label(self.screenshot_path)

    def build_user_interface(self):
        self.label = QtWidgets.QLabel(self)
        self.drawing = False
        self.widget = QtWidgets.QWidget(self)
        self.widget.setGeometry(QtCore.QRect(0, 0, 351, 34))
        self.widget.setObjectName("widget")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.widget)
        self.horizontalLayout.setSizeConstraint(
            QtWidgets.QLayout.SetMaximumSize)
        self.horizontalLayout.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.lineEdit = QtWidgets.QLineEdit(self.widget)
        size_policy = QtWidgets.QSizePolicy(
            QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        size_policy.setHorizontalStretch(0)
        size_policy.setVerticalStretch(0)
        size_policy.setHeightForWidth(
            self.lineEdit.sizePolicy().hasHeightForWidth())
        self.lineEdit.setSizePolicy(size_policy)
        self.lineEdit.setMinimumSize(QtCore.QSize(25, 25))
        self.lineEdit.setMaximumSize(QtCore.QSize(25, 16777215))
        self.lineEdit.setMaxLength(1)
        self.lineEdit.setObjectName("lineEdit")
        self.horizontalLayout.addWidget(self.lineEdit)
        self.pushButton = QtWidgets.QPushButton(self.widget)
        self.pushButton.setMaximumSize(QtCore.QSize(50, 16777215))
        self.pushButton.setObjectName("pushButton")
        self.horizontalLayout.addWidget(self.pushButton)
        self.label0 = QtWidgets.QLabel(self.widget)
        self.label0.setMinimumSize(QtCore.QSize(25, 25))
        self.label0.setStyleSheet(
            "color: rgb(0, 0, 0);\n"
            "border-radius: 10px;\n"
            "background-color: qlineargradient(spread:pad, x1:0, y1:0, x2:1, "
            "y2:1, stop:0 rgba(61, 255, 0, 255), stop:1 rgba(226, 255, 0, "
            "255));\n "
        )
        self.label0.setAlignment(QtCore.Qt.AlignCenter)
        self.label0.setObjectName("label")
        self.horizontalLayout.addWidget(self.label0)
        self.pushButton.pressed.connect(self.register_key)
        self.label.setSizePolicy(
            QtWidgets.QSizePolicy.Ignored, QtWidgets.QSizePolicy.Ignored
        )
        self.label.resize(800, 600)
        self.setContentsMargins(0, 0, 0, 0)
        self.label.setContentsMargins(0, 0, 0, 0)

    def set_screenshot_to_label(self, screenshot_path):
        """
        Sets the pixmap of a QLabel to the path provided by the screenshot path
        :param screenshot_path: the full path to the screenshot file (*.png)
        :type screenshot_path: str
        :return: None
        :rtype: None
        """
        self.pixmap = QtGui.QPixmap(screenshot_path)
        self.label.resize(
            int(0.5 * self.pixmap.width()),
            int(0.5 * self.pixmap.height())
        )
        self.resize(
            int(0.5 * self.pixmap.width()),
            int(0.5 * self.pixmap.height())
        )

        self.show()
        self.resize(self.label.size())
        self.label.setPixmap(self.pixmap)
        self.label.setMinimumSize(1, 1)
        self.label.setMaximumSize(
            int(0.5 * self.pixmap.width()), int(0.5 * self.pixmap.height())
        )
        self.setMaximumSize(
            int(0.5 * self.pixmap.width()),
            int(0.5 * self.pixmap.height())
        )
        self.label.installEventFilter(self)
        layout = QtWidgets.QVBoxLayout(self)
        layout.addWidget(self.label)
        self.pushButton.setText("OK")
        self.label0.setWordWrap(True)
        self.label0.setText(
            "Click the point, and enter char in textbox and "
            "press OK to continue."
        )

    def register_key(self):
        relx = self.fixed_pos[0] / self.label.width()
        rely = self.fixed_pos[1] / self.label.height()
        fixx = relx * int(self.dimensions[0])
        fixy = rely * int(self.dimensions[1])
        char = self.lineEdit.text()[:1]
        print("Successfully registered {ch} "
              "with position  ({x}, {y})".format(ch=char, x=fixx, y=fixy))
        self.core.add_position(char, (fixx, fixy))
        self.label0.setText(
            "SUCCESS! "
            "Add a new point and enter char; "
            "close the window to finish adding."
        )

    def eventFilter(self, source, event):
        if source is self.label and event.type() == QtCore.QEvent.Resize:
            self.label.setPixmap(
                self.pixmap.scaled(self.label.size(),
                                   QtCore.Qt.KeepAspectRatio)
            )
        return super(MapperUI, self).eventFilter(source, event)

    def mousePressEvent(self, event):
        if event.button() == Qt.LeftButton:
            self.last_found_point = event.pos()
            self.fixed_pos[0] = int(event.pos().x())
            self.fixed_pos[1] = int(event.pos().y())
            print(self.last_found_point, "LAST")
            self.last_found_point = self.label.mapFromParent(
                event.pos())  # this is working fine now
            # self.label.setPixmap(QPixmap.fromImage(self.image))

    def mouseMoveEvent(self, event):
        if event.buttons() & Qt.LeftButton:
            # painter.setPen(QPen(self.brushColor,
            # self.brushSize, Qt.SolidLine, Qt.RoundCap,Qt.RoundJoin))
            # painter.drawLine(
            # self.label.mapFromParent(event.pos()),self.last_found_point)
            self.last_found_point = self.label.mapFromParent(
                event.pos())  # this is working fine now
            print(self.last_found_point, "MOVE")
            self.fixed_pos[0] = int(event.pos().x())
            self.fixed_pos[1] = int(event.pos().y())
            # self.label.setPixmap(QPixmap.fromImage(self.image))

    def mouseReleaseEvent(self, event):
        if event.button == Qt.LeftButton:
            # self.drawing = False
            self.label.setPixmap(QPixmap.fromImage(self.image))

    def closeEvent(self, event):
        # do stuff
        message_box = QMessageBox()
        message_box.setText(
            "Save changes and exit?"
        )
        vals = ["{} → {}".format(
            x, self.core.config[x]) for x in self.core.config]
        message_box.setInformativeText(
            "Mapper has unsaved mappings: {val}. Do you want to save the "
            "current mappings?".format(val=', '.join(vals))
        )
        message_box.setStandardButtons(
            QMessageBox.Yes | QMessageBox.No | QMessageBox.Cancel)
        user_message_box_response = message_box.exec()
        if user_message_box_response == QMessageBox.Yes:
            print("Registration process completed.")
            print("Registered mappings are : ", self.core.config)
            print("Writing configuration file...")
            self.core.create_configuration()
            print("Mapper completed successfully!")
            event.accept()
        elif user_message_box_response == QMessageBox.No:
            print("Not saving mapper configuration to json file")
            event.accept()
        else:
            event.ignore()



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import logging
import platform

if platform.system() == 'Windows':
    # Windows OS > 7
    from guiscrcpy.platform.windows import Windows as System
elif platform.system() == "Linux":
    # GNU/Linux OS
    from guiscrcpy.platform.linux import Linux as System
elif platform.system() == "Darwin":
    # MacOS
    from guiscrcpy.platform.darwin import Darwin as System
else:
    logging.warning("Attempting to run guiscrcpy on utested OS")
    from guiscrcpy.platform.linux import Linux as System
# Other OSes should benefit from Linux config

System()



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

from PyQt5 import QtCore
from PyQt5.QtWidgets import QMainWindow, QFileDialog, QDialog

from guiscrcpy.ux import Ui_SettingsWindow


class InterfaceSettings(QMainWindow, Ui_SettingsWindow):
    # there was a Dialog in the bracket
    def __init__(self, parent):
        QMainWindow.__init__(self)
        Ui_SettingsWindow.__init__(self)
        self.setupUi(self)
        self.parent = parent
        self.commands = []
        self.checkboxes = {
            self.a1: [[None], '--always-on-top', 0],
            self.a2: [[self.a2c1, self.a2c2], '--crop {}:{}', 1],
            self.a3: [[self.a3e1], '--max-fps {}'],
            self.a4: [[None], '--prefer-text'],
            self.a5: [[self.a5c1], '--push-target {}'],
            self.a6: [[self.a6c1], '--record {}'],
            self.a8: [[self.a8c1], '--serial {}'],
            self.a9: [[None], '--window-borderless'],
            self.b0: [[self.b0c1], '--window-title {}'],
            self.b1: [[self.b1c1, self.b1c1], '--window-x {} --window-y {}'],
            self.b2: [[self.b2c1, self.b2c2],
                      '--window-width {} --window-height {}'],
        }

    def init(self):
        self.updatebutton.clicked.connect(self.complete)
        self.a6d1.clicked.connect(self.file_chooser)
        self.show()

    def file_chooser(self):
        dialog = QFileDialog()
        dialog.setFilter(dialog.filter() | QtCore.QDir.Hidden)
        dialog.setDefaultSuffix('mp4')
        dialog.setAcceptMode(QFileDialog.AcceptSave)
        dialog.setNameFilters(['H.264 (*.mp4)', 'MKV (*.mkv)'])
        if dialog.exec_() == QDialog.Accepted:
            self.a6c1.setText(dialog.selectedFiles()[0])

    def checkboxes_act(self, args):
        pass

    def complete(self):
        x = []
        for i in self.checkboxes:
            if i.isChecked():
                box = self.checkboxes[i]
                cmd = box[1]
                cmd_args = []
                for j in box[0]:
                    if j is None:
                        break
                    else:
                        try:
                            arg = j.text()
                            print(arg)
                        except (AttributeError, NameError, ValueError):
                            arg = j.value()
                            print(arg)
                        cmd_args.append(arg)
                else:
                    cmd = cmd.format(*cmd_args)
                print(cmd)
                x.append(cmd)
        print(x)
        self.hide()
        self.parent.cmx = x

    def cancel(self):
        pass



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import time

from qtpy.QtWidgets import QMainWindow

from ..network.network import NetworkManager
from ..platform.platform import System
from . import Ui_NetworkUI


class InterfaceNetwork(QMainWindow, Ui_NetworkUI):
    """
    Network manager UI UX Kit for guiscrcpy
    Scans the open IP Addresses connected on the system,
    on Linux and Mac only, as far as tested
    Does not work satisfactorily on Windows.
    """

    def __init__(self, adb):
        QMainWindow.__init__(self)
        Ui_NetworkUI.__init__(self)
        self.os = System()
        self.setupUi(self)
        self.adb = adb
        self.nm = NetworkManager()

    def init(self):
        """
        Connect buttons to sig
        :return:
        """
        self.nm_connect.pressed.connect(self.connect)
        if self.os.system() == 'Windows':
            # FIXME: Port scanning is not working on Windows at the moment.
            self.nm_det.setText(
                "Enter the IP address in the text box and press connect")
            self.nm_refresh.setEnabled(False)
        else:
            self.nm_refresh.pressed.connect(self.refresh)
            self.nm_det.setText("Click Refresh to load IP addresses")
        self.tcpip.pressed.connect(self.tcpip_launch)

    def tcpip_launch(self):
        self.adb.command('-d tcpip 5555')
        self.nm_det.setText(
            "Now disconnect your device, and enter the IP address, and connect"
        )
        return

    def connect(self):
        try:
            ip = self.listView.currentItem().text()
        except AttributeError:
            # The IP Address in the ListView has precedence over the IP address
            # in the text box
            if not self.lineEdit.text().strip().isspace() or len(
                    self.lineEdit.text().strip()) != 0:
                if ':' in self.lineEdit.text():
                    self.nm_det.setText("Please provide the port in the "
                                        "'port' text box")
                    return
                if self.lineEdit.text().count('.') == 3:
                    ip = self.lineEdit.text().strip().lower()
                else:
                    self.nm_det.setText("Invalid IP address in text box")
                    return
            else:
                if self.os.system() == 'Windows':
                    self.nm_det.setText(
                        "Please enter an IP address in the text box")
                else:
                    self.nm_det.setText(
                        "Please enter an IP address in the text box. / "
                        "Click refresh")
                return

        sp = self.adb.command('connect {}:5555'.format(ip))
        count = 0
        while True:
            count += 1
            readout = sp.stdout.readline().decode()
            if 'failed' in readout:
                self.nm_det.setText(
                    'Device failed to get connected (is it an Android dev?')
                return
            if 'connected' in readout:
                print(readout)
                break
            if count > 30:
                self.nm_det.setText('Device connect failed: Timeout')
            else:
                time.sleep(1)
        self.nm_det.setText(
            "Connected to IP:{}:{}".format(ip, self.spinBox.value()))

    def refresh(self):
        self.listView.clear()
        nm_map_network_devices = self.nm.map_network()
        print("Detected IP Addresses:", nm_map_network_devices)
        self.listView.addItems(nm_map_network_devices)



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import os
import logging
import shutil
from subprocess import Popen, PIPE, call, TimeoutExpired

from ..lib.utils import decode_process, shellify as _
from ..platform.platform import System
from ..install.finder import open_exe_name_dialog

environment = System()


def get(ls, idx, default=""):
    try:
        return ls[idx]
    except IndexError:
        return default


def _get_dimension_raw_noexcept(path, device_id=None):
    if device_id:
        shell_adb = Popen(
            _("{} -s {} shell wm size".format(path, device_id)),
            stdout=PIPE, stderr=PIPE)
    else:
        shell_adb = Popen(_("{} shell wm size".format(path)),
                          stdout=PIPE, stderr=PIPE)
    return shell_adb


class ScrcpyNotFoundError(FileNotFoundError):
    pass


class ScrcpyServerNotFoundError(FileNotFoundError):
    pass


class ScrcpyBridge:
    def __init__(self, path=None):
        if path is not None:
            self.path = path
        elif shutil.which('scrcpy'):
            self.path = shutil.which('scrcpy')
        else:
            self.path = open_exe_name_dialog(None, 'scrcpy')
        if self.path is None:
            raise ScrcpyNotFoundError("Could not find `scrcpy` on PATH. Make "
                                      "sure scrcpy is installed and "
                                      "accessible from the terminal.")
        if os.getenv('SCRCPY_LDD'):
            if os.getenv('LD_LIBRARY_PATH'):
                os.environ['LD_LIBRARY_PATH'] += os.getenv('SCRCPY_LDD')
            else:
                os.environ['LD_LIBRARY_PATH'] = os.getenv('SCRCPY_LDD')

    def start(self, args, stdout=PIPE, stderr=PIPE):
        proc = Popen(
            _("{} {}".format(self.path, args)),
            stdout=stdout,
            stderr=stderr,
        )
        return proc

    def get_path(self):
        return self.path


class AdbNotFoundError(FileNotFoundError):
    pass


class AdbRuntimeError(RuntimeError):
    pass


class AndroidDebugBridge:
    def __init__(self, path=None):
        if path is not None:
            self.path = path
        elif shutil.which('adb') is not None:
            self.path = shutil.which('adb')
        else:
            self.path = open_exe_name_dialog(None, 'adb')
        if self.path is None:
            AdbNotFoundError("Could not find `adb` on PATH. "
                             "Make sure adb is installed accessible "
                             "from the terminal")

    def shell_input(self, command, device_id=None):
        path = self.path
        if device_id:
            Popen(
                _("{} -s {} shell input {}".format(path, device_id, command)),
                stdout=PIPE,
                stderr=PIPE,
            )
        else:
            Popen(
                _("{} shell input {}".format(path, command)),
                stdout=PIPE,
                stderr=PIPE,
            )

    def get_path(self):
        return self.path

    def kill_adb_server(self):
        self.command(self.path, "kill-server")

    def get_dimensions(self, device_id=None):
        shell_adb = _get_dimension_raw_noexcept(
            path=self.path, device_id=device_id
        )
        try:
            if shell_adb.wait(timeout=3) != 0:
                print("E: Command 'adb shell wm size' exited with {}".format(
                    shell_adb.returncode))
                return False
        except TimeoutExpired:
            print("E: adb falied; timeout exceeded 10s, killing and "
                  "respawining adb")
            self.kill_adb_server()
            if isinstance(device_id, str) and device_id.count('.') >= 3:
                self.command(self.path, "connect {}".format(device_id))
            shell_adb = _get_dimension_raw_noexcept(
                path=self.path, device_id=device_id
            )
            if shell_adb.wait(timeout=8) != 0:
                print("E: Command 'adb shell wm size' exited with {}".format(
                    shell_adb.returncode))
                return False
        raw_dimensions = shell_adb.stdout.read().decode().strip('\n')
        for i in ['Override size', 'Physical size']:
            if i in raw_dimensions:
                out = raw_dimensions[raw_dimensions.find(i):]
                out_decoded = out.split(':')[1].strip()
                dimension_values = out_decoded.split('x')
                return dimension_values

        # As the for loop did not find any device; and hence we have reached
        # this line. Announce to the user regarding the same
        logging.error(
            "AndroidDeviceError: adb shell wm size did not return "
            "'Physical Size' or 'Override Size'"
        )
        return False

    def shell(self, command, device_id=None):
        if device_id:
            po = Popen(_("{} -s {} shell {}".format(
                self.path, device_id, command)),
                stdout=PIPE, stderr=PIPE)
        else:
            po = Popen(_("{} shell {}".format(self.path, command)),
                       stdout=PIPE, stderr=PIPE)
        return po

    def command(self, command, device_id=None):
        if device_id:
            adb_shell_output = Popen(
                _("{} -s {} {}".format(self.path, device_id, command)),
                stdout=PIPE,
                stderr=PIPE)
        else:
            adb_shell_output = Popen(_("{} {}".format(self.path, command)),
                                     stdout=PIPE, stderr=PIPE)
        return adb_shell_output

    def tcpip(self, port=5555, identifier=""):
        if identifier:
            command = "{path} -s {identifier} -d tcpip {port}"
        else:
            command = "{path} -d tcpip {port}"
        exit_code = call(
            _(command.format(path=self.path, port=port,
                             identifier=identifier)),
            stdout=PIPE,
            stderr=PIPE
        )
        return exit_code

    def devices(self):
        proc = Popen(_(self.path + " devices"), stdout=PIPE)
        output = [[y.strip() for y in x.split('\t')]
                  for x in decode_process(proc)[1:]][:-1]

        logging.debug("ADB: {}".format(output))
        return output

    def devices_detailed(self):
        proc = Popen(_(self.path + " devices -l"), stdout=PIPE)
        output = [[y.strip() for y in x.split()]
                  for x in decode_process(proc)[1:]][:-1]
        devices_found = []
        for device in output:
            # https://github.com/srevinsaju/guiscrcpy/issues/117
            if 'udev' in device and 'permission' in device:
                # This is an error with some linux and Windows OSes
                # This happens because the udev is not configured
                # and linux adb does not have access to reading the device
                # the status hence should be 'no_permission'
                status = 'no_permission'
            else:
                status = device[1]
            description = {
                'identifier': device[0],
                'status': status,
                'product': get(device, 2, ':').split(':')[-1],
                'model': get(device, 3, ':').split(':')[-1],
                'device': get(device, 4, ':').split(':')[-1],
                'transport_id': get(device, 5, ':').split(':')[-1]
            }
            devices_found.append(description)
        logging.debug("ADB: {}".format(devices_found))
        return devices_found



# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'settings.ui'
##
## Created by: Qt User Interface Compiler version 5.15.0
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import (QCoreApplication, QDate, QDateTime, QMetaObject,
    QObject, QPoint, QRect, QSize, QTime, QUrl, Qt)
from PySide2.QtGui import (QBrush, QColor, QConicalGradient, QCursor, QFont,
    QFontDatabase, QIcon, QKeySequence, QLinearGradient, QPalette, QPainter,
    QPixmap, QRadialGradient)
from PySide2.QtWidgets import *


class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        if not MainWindow.objectName():
            MainWindow.setObjectName(u"MainWindow")
        MainWindow.resize(441, 447)
        self.centralwidget = QWidget(MainWindow)
        self.centralwidget.setObjectName(u"centralwidget")
        self.layoutWidget = QWidget(self.centralwidget)
        self.layoutWidget.setObjectName(u"layoutWidget")
        self.layoutWidget.setGeometry(QRect(0, 10, 441, 408))
        self.gridLayout = QGridLayout(self.layoutWidget)
        self.gridLayout.setSpacing(0)
        self.gridLayout.setObjectName(u"gridLayout")
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.b1c2 = QLineEdit(self.layoutWidget)
        self.b1c2.setObjectName(u"b1c2")

        self.gridLayout.addWidget(self.b1c2, 10, 4, 1, 2)

        self.label_6 = QLabel(self.layoutWidget)
        self.label_6.setObjectName(u"label_6")
        self.label_6.setAlignment(Qt.AlignCenter)

        self.gridLayout.addWidget(self.label_6, 11, 3, 1, 1)

        self.label_5 = QLabel(self.layoutWidget)
        self.label_5.setObjectName(u"label_5")
        self.label_5.setAlignment(Qt.AlignCenter)

        self.gridLayout.addWidget(self.label_5, 11, 1, 1, 1)

        self.a1 = QCheckBox(self.layoutWidget)
        self.a1.setObjectName(u"a1")

        self.gridLayout.addWidget(self.a1, 0, 0, 1, 1)

        self.label_4 = QLabel(self.layoutWidget)
        self.label_4.setObjectName(u"label_4")
        self.label_4.setMinimumSize(QSize(25, 0))
        self.label_4.setAlignment(Qt.AlignCenter)

        self.gridLayout.addWidget(self.label_4, 10, 3, 1, 1)

        self.a4 = QCheckBox(self.layoutWidget)
        self.a4.setObjectName(u"a4")

        self.gridLayout.addWidget(self.a4, 4, 0, 1, 1)

        self.a6d1 = QToolButton(self.layoutWidget)
        self.a6d1.setObjectName(u"a6d1")

        self.gridLayout.addWidget(self.a6d1, 6, 1, 1, 1)

        self.b2c1 = QLineEdit(self.layoutWidget)
        self.b2c1.setObjectName(u"b2c1")

        self.gridLayout.addWidget(self.b2c1, 11, 2, 1, 1)

        self.a3 = QCheckBox(self.layoutWidget)
        self.a3.setObjectName(u"a3")

        self.gridLayout.addWidget(self.a3, 3, 0, 1, 1)

        self.a8c1 = QLineEdit(self.layoutWidget)
        self.a8c1.setObjectName(u"a8c1")

        self.gridLayout.addWidget(self.a8c1, 7, 1, 1, 5)

        self.label = QLabel(self.layoutWidget)
        self.label.setObjectName(u"label")
        self.label.setEnabled(False)
        self.label.setAlignment(Qt.AlignCenter)

        self.gridLayout.addWidget(self.label, 1, 1, 1, 1)

        self.a9 = QCheckBox(self.layoutWidget)
        self.a9.setObjectName(u"a9")

        self.gridLayout.addWidget(self.a9, 8, 0, 1, 1)

        self.label_3 = QLabel(self.layoutWidget)
        self.label_3.setObjectName(u"label_3")
        self.label_3.setAlignment(Qt.AlignCenter)

        self.gridLayout.addWidget(self.label_3, 10, 1, 1, 1)

        self.updatebutton = QPushButton(self.layoutWidget)
        self.updatebutton.setObjectName(u"updatebutton")

        self.gridLayout.addWidget(self.updatebutton, 12, 2, 1, 4)

        self.a6 = QCheckBox(self.layoutWidget)
        self.a6.setObjectName(u"a6")

        self.gridLayout.addWidget(self.a6, 6, 0, 1, 1)

        self.a5c1 = QLineEdit(self.layoutWidget)
        self.a5c1.setObjectName(u"a5c1")

        self.gridLayout.addWidget(self.a5c1, 5, 1, 1, 5)

        self.a8 = QCheckBox(self.layoutWidget)
        self.a8.setObjectName(u"a8")

        self.gridLayout.addWidget(self.a8, 7, 0, 1, 1)

        self.b1c1 = QLineEdit(self.layoutWidget)
        self.b1c1.setObjectName(u"b1c1")

        self.gridLayout.addWidget(self.b1c1, 10, 2, 1, 1)

        self.label_2 = QLabel(self.layoutWidget)
        self.label_2.setObjectName(u"label_2")
        self.label_2.setEnabled(False)
        self.label_2.setAlignment(Qt.AlignCenter)

        self.gridLayout.addWidget(self.label_2, 1, 3, 1, 1)

        self.b1 = QCheckBox(self.layoutWidget)
        self.b1.setObjectName(u"b1")

        self.gridLayout.addWidget(self.b1, 10, 0, 1, 1)

        self.a2c1 = QLineEdit(self.layoutWidget)
        self.a2c1.setObjectName(u"a2c1")
        self.a2c1.setEnabled(False)

        self.gridLayout.addWidget(self.a2c1, 1, 2, 1, 1)

        self.b2c2 = QLineEdit(self.layoutWidget)
        self.b2c2.setObjectName(u"b2c2")

        self.gridLayout.addWidget(self.b2c2, 11, 4, 1, 2)

        self.b2 = QCheckBox(self.layoutWidget)
        self.b2.setObjectName(u"b2")

        self.gridLayout.addWidget(self.b2, 11, 0, 1, 1)

        self.a2 = QCheckBox(self.layoutWidget)
        self.a2.setObjectName(u"a2")
        self.a2.setEnabled(False)

        self.gridLayout.addWidget(self.a2, 1, 0, 1, 1)

        self.b0 = QCheckBox(self.layoutWidget)
        self.b0.setObjectName(u"b0")

        self.gridLayout.addWidget(self.b0, 9, 0, 1, 1)

        self.b0c1 = QLineEdit(self.layoutWidget)
        self.b0c1.setObjectName(u"b0c1")

        self.gridLayout.addWidget(self.b0c1, 9, 1, 1, 5)

        self.a5 = QCheckBox(self.layoutWidget)
        self.a5.setObjectName(u"a5")

        self.gridLayout.addWidget(self.a5, 5, 0, 1, 1)

        self.a6c1 = QLineEdit(self.layoutWidget)
        self.a6c1.setObjectName(u"a6c1")

        self.gridLayout.addWidget(self.a6c1, 6, 2, 1, 4)

        self.a2c2 = QLineEdit(self.layoutWidget)
        self.a2c2.setObjectName(u"a2c2")
        self.a2c2.setEnabled(False)

        self.gridLayout.addWidget(self.a2c2, 1, 4, 1, 2)

        self.a3e1 = QSpinBox(self.layoutWidget)
        self.a3e1.setObjectName(u"a3e1")

        self.gridLayout.addWidget(self.a3e1, 3, 1, 1, 5)

        MainWindow.setCentralWidget(self.centralwidget)
        self.statusbar = QStatusBar(MainWindow)
        self.statusbar.setObjectName(u"statusbar")
        MainWindow.setStatusBar(self.statusbar)

        self.retranslateUi(MainWindow)

        QMetaObject.connectSlotsByName(MainWindow)
    # setupUi

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QCoreApplication.translate("MainWindow", u"Settings", None))
        self.label_6.setText(QCoreApplication.translate("MainWindow", u"h", None))
        self.label_5.setText(QCoreApplication.translate("MainWindow", u"w", None))
        self.a1.setText(QCoreApplication.translate("MainWindow", u"Always on Top", None))
        self.label_4.setText(QCoreApplication.translate("MainWindow", u"y", None))
        self.a4.setText(QCoreApplication.translate("MainWindow", u"Prefer Text", None))
        self.a6d1.setText(QCoreApplication.translate("MainWindow", u"...", None))
        self.a3.setText(QCoreApplication.translate("MainWindow", u"Max Frame / second (FPS)", None))
        self.label.setText(QCoreApplication.translate("MainWindow", u"x", None))
        self.a9.setText(QCoreApplication.translate("MainWindow", u"Borderless Window", None))
        self.label_3.setText(QCoreApplication.translate("MainWindow", u"x", None))
        self.updatebutton.setText(QCoreApplication.translate("MainWindow", u"Update", None))
        self.a6.setText(QCoreApplication.translate("MainWindow", u"Record File", None))
        self.a8.setText(QCoreApplication.translate("MainWindow", u"Serial", None))
        self.label_2.setText(QCoreApplication.translate("MainWindow", u"y", None))
        self.b1.setText(QCoreApplication.translate("MainWindow", u"Window position", None))
        self.b2.setText(QCoreApplication.translate("MainWindow", u"Window size", None))
        self.a2.setText(QCoreApplication.translate("MainWindow", u"Crop Width", None))
        self.b0.setText(QCoreApplication.translate("MainWindow", u"Window Title", None))
        self.a5.setText(QCoreApplication.translate("MainWindow", u"Push Target", None))
    # retranslateUi




#!/usr/bin/env python3
"""

GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.

"""

from setuptools import setup
from setuptools import find_packages
import os
import platform

try:
    this_directory = os.path.abspath(os.path.dirname(__file__))
    with open(
        os.path.join(this_directory, 'README.md'),
        encoding='utf-8'
    ) as f:
        long_description = f.read()
except FileNotFoundError:
    long_description = \
        "Open Source Android Screen Mirroring System by @srevinsaju"

requirements = ['PyQt5>=5.14,<5.16', 'pynput', 'qtpy', 'click', 'colorama']
if platform.system() == 'Windows':
    requirements.extend(['pywin32', 'psutil'])
elif platform.system() == 'Linux':
    requirements.extend(['psutil', 'cairosvg'])

data_files = [
        ('share/applications', ['guiscrcpy.desktop']),
        ('share/icons/hicolor/scalable/apps', ['appimage/guiscrcpy.png']),
    ]

setup(
    name='guiscrcpy',
    version='4.6.0',
    description='An Open Source - Fast - Android Screen Mirroring system.',
    long_description=long_description,
    long_description_content_type='text/markdown',
    license='GPL v3',
    author='srevinsaju',
    author_email="srevin03@gmail.com",
    packages=find_packages(),
    data_files=data_files,
    extras_require={'pyqt5': 'PyQt5', 'pyside2': 'PySide2'},
    url="https://srevinsaju.github.io/guiscrcpy",
    download_url="https://github.com/srevinsaju/guiscrcpy/archive/master.zip",
    include_package_data=True,
    install_requires=requirements,
    scripts=["scripts/guiscrcpy"],
    entry_points={'console_scripts': ['guiscrcpy = guiscrcpy.cli:cli']},  # noqa: E501
    classifiers=[
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.8',
        'Operating System :: MacOS :: MacOS X',
        'Operating System :: Microsoft :: Windows',
        'Operating System :: POSIX',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)'
    ],
)



GUISCRCPY_DEVICE = \
    """[Desktop Entry]
Name={identifier}
GenericName=guiscrcpy
Comment=Open Source Android Screen Mirroring System
Exec={command}
Icon={icon_path}
Type=Application
Categories=Utility;Development;
StartupWMClass=UGENE
"""



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

try:
    import psutil
    psutil_present = True
except ModuleNotFoundError:
    psutil_present = False


def is_running(process_name):
    if psutil_present:
        # Iterate over the all the running process
        for proc in psutil.process_iter():
            try:
                # Check if process name contains the given name string.
                if process_name.lower() in proc.name().lower():
                    return True
            except (
                psutil.NoSuchProcess,
                psutil.AccessDenied,
                psutil.ZombieProcess
            ):
                pass
    return False



"""
GUISCRCPY by srevinsaju
Get it on : https://github.com/srevinsaju/guiscrcpy
Licensed under GNU Public License

This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program.  If not, see <https://www.gnu.org/licenses/>.
"""

import logging
import os

from guiscrcpy.version import VERSION

desktop = \
    """
[Desktop Entry]
Version={v}
Name=guiscrcpy
GenericName=guiscrcpy
Comment=Open Source Android Screen Mirroring System
Exec=guiscrcpy
Icon={icon_path}
Type=Application
Categories=Utility;Development;
StartupWMClass=UGENE
"""


class Linux:
    def __init__(self):
        pass

    def cfgpath(self):
        return self.make_config()

    @staticmethod
    def make_config():
        if os.getenv('XDG_CONFIG_HOME') is None:
            path = os.path.expanduser("~/.config/guiscrcpy/")
        else:
            path = os.getenv('XDG_CONFIG_HOME').split(":")[0] + "/guiscrcpy"
        if not os.path.exists(path):
            try:
                os.makedirs(path)
            except Exception as e:
                logging.error(
                    "Error creating configuration filename in dir {path}. "
                    "Error code:{e}"
                    .format(
                        path=path,
                        e=e
                    ))
        return path

    @staticmethod
    def create_desktop(desktop_file=None,
                       desktop_file_name='guiscrcpy.desktop'):
        """
        Create Desktop filename for Linux in ~/.local level
        :return:
        """
        if desktop_file:
            desk = desktop_file
        else:
            desk = desktop.format(
                v=VERSION,
                icon_path=os.path.join(
                    os.path.abspath(
                        os.path.dirname(
                            os.path.dirname(__file__)
                        )
                    ),
                    'ui', 'ui', 'guiscrcpy_logo.png'
                )
            )
        if os.getenv('XDG_DESKTOP_DIR'):
            desktop_dir = os.getenv('XDG_DESKTOP_DIR')
        else:
            if os.path.exists(os.path.expanduser('~/Desktop')):
                desktop_dir = os.path.expanduser('~/Desktop')
            elif os.path.exists(os.path.expanduser('~/desktop')):
                desktop_dir = os.path.expanduser('~/desktop')
            else:
                desktop_dir = False
        if desktop_dir:
            with open(os.path.join(desktop_dir, desktop_file_name),
                      'w') as w:
                w.write(desk)
            return desktop_dir
        else:
            return False

    @staticmethod
    def install_fonts():
        # deprecate install fonts for Linux
        return True

    @staticmethod
    def system():
        return 'Linux'

    def increment(self):
        pass

    @staticmethod
    def paths():
        return ['bin', '/usr/bin', '~/.local/bin', '~/bin', '/usr/local/bin']



from qtpy.QtWidgets import QFileDialog


def open_exe_name_dialog(parent, appname):
    options = QFileDialog.Options()
    options |= QFileDialog.DontUseNativeDialog
    file_name, _ = \
        QFileDialog.getOpenFileName(
            parent,
            "{} could not be found. Please locate it manually".format(appname),
            "",
            "Valid {} executable (*);;".format(appname),
            options=options
        )
    if file_name:
        print(file_name)
        return file_name
    else:
        print("No file is selected. guiscrcpy is likely to fail")
